/*
TECNISA - TECNOLOGIA EM INFORMTICA

NOME: CALCVALRSERV, CALCEFETMINI, PRECOCORR, OPENEFETMINCUR

DESCRIO:
PROCEDIMENTO RETORNO DO VALOR DO SERVICO E QUANTIDADE POR CLIENTE.

CRIAO:
19/12/2001 - ANA PAULA DA SILVA

Manuteno:
03/11/2006 - Pedro Nerino Viol de Lima

Procedure transformada em Funo.
*/

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCVALRSERV' AND
                 TYPE = 'P' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP PROCEDURE CALCVALRSERV
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCVALRSERV' AND
                 TYPE = 'FN' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP FUNCTION CALCVALRSERV
GO

CREATE FUNCTION CALCVALRSERV
(
   @P_CDFILIAL   VARCHAR(04),
   @P_CDCLIENTE  VARCHAR(21),
   @P_CDSERVFILI VARCHAR(05),
   @P_DTFATURAM  DATETIME,
   @P_CDTURNO    VARCHAR(1))
   RETURNS DOUBLE PRECISION

AS
BEGIN
   DECLARE @VRSERVICOAUX FLOAT;
   DECLARE @VRSERVICOFER FLOAT;
   DECLARE @VRSERVICODOM FLOAT;
   DECLARE @VRSERVICOSEG FLOAT;
   DECLARE @VRSERVICOTER FLOAT;
   DECLARE @VRSERVICOQUA FLOAT;
   DECLARE @VRSERVICOQUI FLOAT;
   DECLARE @VRSERVICOSEX FLOAT;
   DECLARE @VRSERVICOSAB FLOAT;
   DECLARE @VRCOUNT      FLOAT;

   SELECT @VRSERVICOAUX = S.VRSERVFATTUR
   FROM SERVCLIETURN S
        /*Valor do turno da maior data de vigncia menor ou igual  data de faturamento*/
        INNER JOIN (SELECT CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, 
                           MAX(DTSERVCLIETURN) AS DTSERVCLIETURN
                     FROM SERVCLIETURN
                     WHERE DTSERVCLIETURN <= @P_DTFATURAM AND
                                 CDFILIAL   = @P_CDFILIAL   AND
                                 CDCLIENTE  = @P_CDCLIENTE  AND
                                 CDSERVFILI = @P_CDSERVFILI AND
                                 CDTURNO    = @P_CDTURNO
                    GROUP BY CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO) MV
           ON MV.CDFILIAL = S.CDFILIAL AND
              MV.CDCLIENTE = S.CDCLIENTE AND
              MV.CDSERVFILI = S.CDSERVFILI AND
              MV.CDTURNO = S.CDTURNO AND
              MV.DTSERVCLIETURN = S.DTSERVCLIETURN
        /*E que seja a ltima alterao para a data de vigncia*/
        INNER JOIN (SELECT CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, 
                           DTSERVCLIETURN, MAX(DTALTSERVCLIETURN) AS DTALTSERVCLIETURN
                     FROM SERVCLIETURN
                     WHERE DTSERVCLIETURN <= @P_DTFATURAM AND
                                 CDFILIAL   = @P_CDFILIAL   AND
                                 CDCLIENTE  = @P_CDCLIENTE  AND
                                 CDSERVFILI = @P_CDSERVFILI AND
                                 CDTURNO    = @P_CDTURNO
                    GROUP BY CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, DTSERVCLIETURN) MA
           ON MA.CDFILIAL = S.CDFILIAL AND
              MA.CDCLIENTE = S.CDCLIENTE AND
              MA.CDSERVFILI = S.CDSERVFILI AND
              MA.CDTURNO = S.CDTURNO AND
              MA.DTSERVCLIETURN = S.DTSERVCLIETURN AND
              MA.DTALTSERVCLIETURN = S.DTALTSERVCLIETURN
   WHERE S.CDFILIAL   = @P_CDFILIAL   AND
         S.CDCLIENTE  = @P_CDCLIENTE  AND
         S.CDSERVFILI = @P_CDSERVFILI AND
         S.CDTURNO    = @P_CDTURNO;

   IF (@VRSERVICOAUX IS NULL) BEGIN
      SELECT @VRSERVICOAUX = MAX(VRSERVFATHIS),
             @VRSERVICOFER = MAX(VRFATUFERHIS),
             @VRSERVICODOM = MAX(VRFATUDOMHIS),
             @VRSERVICOSEG = MAX(VRFATUSEGHIS),
             @VRSERVICOTER = MAX(VRFATUTERHIS),
             @VRSERVICOQUA = MAX(VRFATUQUAHIS),
             @VRSERVICOQUI = MAX(VRFATUQUIHIS),
             @VRSERVICOSEX = MAX(VRFATUSEXHIS),
             @VRSERVICOSAB = MAX(VRFATUSABHIS)
         FROM HISTSERVFATU
         WHERE CDFILIAL     = @P_CDFILIAL   AND
               CDCLIENTE    = @P_CDCLIENTE  AND
               CDSERVFILI   = @P_CDSERVFILI AND
               DTALTEFATHIS = (SELECT MAX(DTALTEFATHIS)
                               FROM HISTSERVFATU H, (SELECT MAX(DTSRVFATUHIS) AS DTSRVFATUHIS
                                                     FROM HISTSERVFATU
                                                     WHERE CDFILIAL = @P_CDFILIAL   
                                                       AND CDCLIENTE = @P_CDCLIENTE  
                                                       AND CDSERVFILI = @P_CDSERVFILI 
                                                       AND DTSRVFATUHIS <= @P_DTFATURAM) X
                               WHERE H.CDFILIAL     = @P_CDFILIAL   
                                 AND H.CDCLIENTE    = @P_CDCLIENTE  
                                 AND H.CDSERVFILI   = @P_CDSERVFILI 
                                 AND H.DTSRVFATUHIS = X.DTSRVFATUHIS) AND
               DTSRVFATUHIS = (SELECT MAX(H.DTSRVFATUHIS)
                               FROM HISTSERVFATU H, (SELECT MAX(DTSRVFATUHIS) AS DTSRVFATUHIS
                                                     FROM HISTSERVFATU
                                                     WHERE CDFILIAL = @P_CDFILIAL   
                                                       AND CDCLIENTE = @P_CDCLIENTE  
                                                       AND CDSERVFILI = @P_CDSERVFILI 
                                                       AND DTSRVFATUHIS <= @P_DTFATURAM) X
                               WHERE H.CDFILIAL     = @P_CDFILIAL   
                                 AND H.CDCLIENTE    = @P_CDCLIENTE  
                                 AND H.CDSERVFILI   = @P_CDSERVFILI 
                                 AND H.DTSRVFATUHIS = X.DTSRVFATUHIS);

      IF (@VRSERVICOAUX IS NULL) BEGIN
         SELECT @VRSERVICOAUX = MAX(VRSERVFATU)  ,
                @VRSERVICOFER = MAX(VRSERVFATFER),
                @VRSERVICODOM = MAX(VRSERVFATDOM),
                @VRSERVICOSEG = MAX(VRSERVFATSEG),
                @VRSERVICOTER = MAX(VRSERVFATTER),
                @VRSERVICOQUA = MAX(VRSERVFATQUA),
                @VRSERVICOQUI = MAX(VRSERVFATQUI),
                @VRSERVICOSEX = MAX(VRSERVFATSEX),
                @VRSERVICOSAB = MAX(VRSERVFATSAB)
         FROM SERVCLIE
         WHERE CDFILIAL   = @P_CDFILIAL   AND
               CDCLIENTE  = @P_CDCLIENTE  AND
               CDSERVFILI = @P_CDSERVFILI;

         IF (@VRSERVICOAUX IS NULL) BEGIN
            SET @VRSERVICOAUX = 0;
         END
         ELSE BEGIN

            SELECT @VRCOUNT = COUNT(*)
            FROM FERIFILI
            WHERE CDFILIAL   = @P_CDFILIAL AND
                  DTFERIFILI = @P_DTFATURAM;

            IF (@VRCOUNT = 0) BEGIN
               SELECT @VRCOUNT = COUNT(*)
               FROM FERICARD
               WHERE CDFILIAL   = @P_CDFILIAL AND
                     DTFERICARD = @P_DTFATURAM;
            END;

            IF (@VRCOUNT > 0) BEGIN
               IF ((@VRSERVICOFER IS NOT NULL) AND (@VRSERVICOFER <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOFER;
               END;
            END
            ELSE BEGIN
               IF ((DATEPART(DW,@P_DTFATURAM) = 1) AND
                   (@VRSERVICODOM IS NOT NULL) AND
                   (@VRSERVICODOM <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICODOM;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 2) AND
                   (@VRSERVICOSEG IS NOT NULL) AND
                   (@VRSERVICOSEG <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOSEG;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 3) AND
                   (@VRSERVICOTER IS NOT NULL) AND
                   (@VRSERVICOTER <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOTER;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 4) AND
                   (@VRSERVICOQUA IS NOT NULL) AND
                   (@VRSERVICOQUA <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOQUA;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 5) AND
                   (@VRSERVICOQUI IS NOT NULL) AND
                   (@VRSERVICOQUI <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOQUI;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 6) AND
                   (@VRSERVICOSEX IS NOT NULL) AND
                   (@VRSERVICOSEX <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOSEX;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 7) AND
                   (@VRSERVICOSAB IS NOT NULL) AND
                   (@VRSERVICOSAB <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOSAB;
               END;
            END;
         END;
      END 
      ELSE BEGIN
            SELECT @VRCOUNT = COUNT(*)
            FROM FERIFILI
            WHERE CDFILIAL   = @P_CDFILIAL AND
                  DTFERIFILI = @P_DTFATURAM;

            IF (@VRCOUNT = 0) BEGIN
               SELECT @VRCOUNT = COUNT(*)
               FROM FERICARD
               WHERE CDFILIAL   = @P_CDFILIAL AND
                     DTFERICARD = @P_DTFATURAM;
            END;

            IF (@VRCOUNT > 0) BEGIN
               IF ((@VRSERVICOFER IS NOT NULL) AND (@VRSERVICOFER <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOFER;
               END;
            END
            ELSE BEGIN
               IF ((DATEPART(DW,@P_DTFATURAM) = 1) AND
                   (@VRSERVICODOM IS NOT NULL) AND
                   (@VRSERVICODOM <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICODOM;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 2) AND
                   (@VRSERVICOSEG IS NOT NULL) AND
                   (@VRSERVICOSEG <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOSEG;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 3) AND
                   (@VRSERVICOTER IS NOT NULL) AND
                   (@VRSERVICOTER <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOTER;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 4) AND
                   (@VRSERVICOQUA IS NOT NULL) AND
                   (@VRSERVICOQUA <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOQUA;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 5) AND
                   (@VRSERVICOQUI IS NOT NULL) AND
                   (@VRSERVICOQUI <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOQUI;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 6) AND
                   (@VRSERVICOSEX IS NOT NULL) AND
                   (@VRSERVICOSEX <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOSEX;
               END;
               IF ((DATEPART(DW,@P_DTFATURAM) = 7) AND
                   (@VRSERVICOSAB IS NOT NULL) AND
                   (@VRSERVICOSAB <> 0)) BEGIN
                  SET @VRSERVICOAUX = @VRSERVICOSAB;
               END;
            END;
      END;
   END;
   RETURN(@VRSERVICOAUX);
END
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCEFETMINI' AND
                 TYPE = 'P' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP PROCEDURE CALCEFETMINI
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCEFETMINI' AND
                 TYPE = 'FN' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP FUNCTION CALCEFETMINI
GO
CREATE FUNCTION CALCEFETMINI
(
   @P_CDFILIAL    VARCHAR(04),
   @P_CDCLIENTE   VARCHAR(21),
   @P_CDSERVFILI  VARCHAR(05),
   @P_CDGRSERVFAT VARCHAR(03),
   @P_DTFATURAM   DATETIME)
   RETURNS FLOAT

AS
BEGIN
   DECLARE @QTEFETMINIAUX FLOAT;
   DECLARE @QTEFETMINIFER FLOAT;
   DECLARE @QTEFETMINIDOM FLOAT;
   DECLARE @QTEFETMINISEG FLOAT;
   DECLARE @QTEFETMINITER FLOAT;
   DECLARE @QTEFETMINIQUA FLOAT;
   DECLARE @QTEFETMINIQUI FLOAT;
   DECLARE @QTEFETMINISEX FLOAT;
   DECLARE @QTEFETMINISAB FLOAT;
   DECLARE @VRCOUNT       FLOAT;

   IF (@P_CDGRSERVFAT IS NULL) BEGIN
      SELECT @QTEFETMINIAUX = QTEFETMINI, @QTEFETMINIFER = QTEFETMINFER,
             @QTEFETMINIDOM = QTEFETMINDOM, @QTEFETMINISEG = QTEFETMINSEG,
             @QTEFETMINITER = QTEFETMINTER, @QTEFETMINIQUA = QTEFETMINQUA,
             @QTEFETMINIQUI = QTEFETMINQUI, @QTEFETMINISEX = QTEFETMINSEX,
             @QTEFETMINISAB = QTEFETMINSAB
      FROM SERVCLIE
      WHERE CDFILIAL = @P_CDFILIAL AND
            CDCLIENTE = @P_CDCLIENTE AND
            CDSERVFILI = @P_CDSERVFILI;
   END
   ELSE BEGIN
      SELECT @QTEFETMINIAUX = QTEFETMINIGSF, @QTEFETMINIFER = QTEFMINFERGSF,
             @QTEFETMINIDOM = QTEFMINDOMGSF, @QTEFETMINISEG = QTEFMINSEGGSF,
             @QTEFETMINITER = QTEFMINTERGSF, @QTEFETMINIQUA = QTEFMINQUAGSF,
             @QTEFETMINIQUI = QTEFMINQUIGSF, @QTEFETMINISEX = QTEFMINSEXGSF,
             @QTEFETMINISAB = QTEFMINSABGSF
      FROM GRUPSERVFAT
      WHERE CDFILIAL = @P_CDFILIAL AND
            CDCLIENTE = @P_CDCLIENTE AND
            CDGRSERVFAT = @P_CDGRSERVFAT;
   END

   IF (@QTEFETMINIAUX IS NULL) BEGIN
      SET @QTEFETMINIAUX = 0;
   END
   ELSE BEGIN
      SELECT @VRCOUNT = COUNT(*)
      FROM FERIFILI
      WHERE CDFILIAL   = @P_CDFILIAL AND
            DTFERIFILI = @P_DTFATURAM;

      IF (@VRCOUNT = 0) BEGIN
         SELECT @VRCOUNT = COUNT(*)
         FROM FERICARD
         WHERE CDFILIAL   = @P_CDFILIAL AND
               DTFERICARD = @P_DTFATURAM;
      END;

      IF (@VRCOUNT > 0) BEGIN
         IF ((@QTEFETMINIFER IS NOT NULL) AND (@QTEFETMINIFER <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINIFER;
         END;
      END
      ELSE BEGIN
         IF ((DATEPART(DW,@P_DTFATURAM) = 1) AND
             (@QTEFETMINIDOM IS NOT NULL)  AND
             (@QTEFETMINIDOM <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINIDOM;
         END;
         IF ((DATEPART(DW,@P_DTFATURAM) = 2) AND
             (@QTEFETMINISEG IS NOT NULL)  AND
             (@QTEFETMINISEG <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINISEG;
         END;
         IF ((DATEPART(DW,@P_DTFATURAM) = 3) AND
             (@QTEFETMINITER IS NOT NULL)    AND
             (@QTEFETMINITER <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINITER;
         END;
         IF ((DATEPART(DW,@P_DTFATURAM) = 4) AND
             (@QTEFETMINIQUA IS NOT NULL)    AND
             (@QTEFETMINIQUA <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINIQUA;
         END;
         IF ((DATEPART(DW,@P_DTFATURAM) = 5) AND
             (@QTEFETMINIQUI IS NOT NULL)    AND
             (@QTEFETMINIQUI <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINIQUI;
         END;
         IF ((DATEPART(DW,@P_DTFATURAM) = 6) AND
             (@QTEFETMINISEX IS NOT NULL)   AND
             (@QTEFETMINISEX <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINISEX;
         END;
         IF ((DATEPART(DW,@P_DTFATURAM) = 7) AND
             (@QTEFETMINISAB IS NOT NULL)    AND
             (@QTEFETMINISAB <> 0)) BEGIN
            SET @QTEFETMINIAUX = @QTEFETMINISAB;
         END;
      END;
   END;
   RETURN(@QTEFETMINIAUX);
END
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'PRECOCORR' AND
                 TYPE = 'TF' 			  AND
                 U.UID = O.UID        AND
                 U.NAME = USER)
DROP FUNCTION PRECOCORR
GO

CREATE FUNCTION PRECOCORR
(  @P_CDFILIAL    VARCHAR(04),
   @P_CDCLIENTE   VARCHAR(21),
   @P_CDSERVFILI  VARCHAR(05),
   @P_CDGRSERVFAT VARCHAR(03),
   @P_QTEFETIVOS  FLOAT,
   @P_QTEFETMINI  FLOAT,
   @P_IDSERVGRUP  VARCHAR(02))

   RETURNS @FN_TABLE TABLE (V_VRSERVICO DOUBLE PRECISION,
                            V_VRPERCCORR DOUBLE PRECISION)
AS
BEGIN
   DECLARE @V_VRPERC      FLOAT;
   DECLARE @V_VRSERVICO   FLOAT;
   DECLARE @V_VRPERCCORR  FLOAT;
   DECLARE @V_VRSERVTOTAL VARCHAR;
   DECLARE @V_VRPERCORTOT VARCHAR;
   DECLARE @V_IDATIVATABCOR VARCHAR(01);
   DECLARE @V_QTEFETVOL FLOAT;

   /* CONSIDERAR VOLUME PROPOSTO*/	
   SELECT @V_QTEFETVOL = ISNULL(MAX(QTVOLPROSERVCLI), 0) 
     FROM SERVCLIE
    WHERE CDFILIAL = @P_CDFILIAL
      AND CDSERVFILI = @P_CDSERVFILI
      AND CDCLIENTE = @P_CDCLIENTE;

   IF @V_QTEFETVOL = 0 BEGIN
      SET @V_QTEFETVOL = @P_QTEFETMINI;
   END; 

   IF (@V_QTEFETVOL <> 0) BEGIN
      SET @V_VRPERC = ((@P_QTEFETIVOS / @V_QTEFETVOL) * 100);
   END;

   SET @V_VRPERCCORR = 1;

   IF (@V_VRSERVICO IS NULL) BEGIN
      SET @V_VRSERVICO = 0;
   END;

   IF (@P_IDSERVGRUP <> 'G') BEGIN
      /* PARA SERVICOS */
      --VERIFICA SE A TABELA DE CORREO EST ATIVA PARA A FILIAL,CLIENTE,SERVIO
      SELECT @V_IDATIVATABCOR = ISNULL(MAX(IDATIVATABCOR), 'N')
        FROM SERVCLIE   
       WHERE CDFILIAL = @P_CDFILIAL
         AND CDCLIENTE = @P_CDCLIENTE
         AND CDSERVFILI = @P_CDSERVFILI;
      IF (@V_IDATIVATABCOR = 'S') OR (SUBSTRING(@P_IDSERVGRUP, 2, 1) = 'S') BEGIN
         SELECT @V_VRPERCCORR = MAX(1 + (VRPECORRSERV/100))
           FROM CORRPRECSERV
          WHERE CDFILIAL = @P_CDFILIAL 
            AND CDCLIENTE = @P_CDCLIENTE 
            AND CDSERVFILI = @P_CDSERVFILI 
            AND @V_VRPERC BETWEEN VRPEINICSERV AND VRPEFIMSERV;
      END;
   END ELSE BEGIN
      /* PARA GRUPOS */
      SELECT @V_VRPERCCORR = MAX(1 + (VRPECORRGRUP/100))
        FROM CORRPRECGRUP
       WHERE (CDFILIAL = @P_CDFILIAL)       AND
             (CDCLIENTE = @P_CDCLIENTE)     AND
             (CDGRSERVFAT = @P_CDGRSERVFAT) AND
             (@V_VRPERC BETWEEN VRPEINICGRUP AND VRPEFIMGRUP)
   END;

   IF (@V_VRPERCCORR IS NULL) BEGIN
      SET @V_VRPERCCORR = 1;
   END;

   SET @V_VRSERVICO = (@V_VRSERVICO * @V_VRPERCCORR);
   INSERT INTO @FN_TABLE VALUES (@V_VRSERVICO, @V_VRPERCCORR);
   RETURN;
END
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCVALRSERVTUR' AND
                 TYPE = 'P' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP PROCEDURE CALCVALRSERVTUR
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCVALRSERVTUR' AND
                 TYPE = 'FN' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP FUNCTION CALCVALRSERVTUR
GO

CREATE FUNCTION CALCVALRSERVTUR
(@P_CDFILIAL    VARCHAR(04),
 @P_CDCLIENTE   VARCHAR(21),
 @P_CDSERVFILI  VARCHAR(05),
 @P_DTFATURAM   DATETIME,
 @P_CDTURNO     VARCHAR(01))
 RETURNS DOUBLE PRECISION

AS
BEGIN

   DECLARE @VrServico      FLOAT;
   DECLARE @VrServicoFer   FLOAT;
   DECLARE @VrServicoDom   FLOAT;
   DECLARE @VrServicoSeg   FLOAT;
   DECLARE @VrServicoTer   FLOAT;
   DECLARE @VrServicoQua   FLOAT;
   DECLARE @VrServicoQui   FLOAT;
   DECLARE @VrServicoSex   FLOAT;
   DECLARE @VrServicoSab   FLOAT;
   DECLARE @VrCount        NUMERIC(3);

   SELECT @VrServico = MAX(S.VRSERVFATTUR), @VrServicoFer = MAX(S.VRSVFATTUFER),
          @VrServicoDom = MAX(S.VRSVFATTUDOM),
          @VrServicoSeg = MAX(S.VRSVFATTUSEG), @VrServicoTer = MAX(S.VRSVFATTUTER),
          @VrServicoQua = MAX(S.VRSVFATTUQUA), @VrServicoQui = MAX(S.VRSVFATTUQUI),
          @VrServicoSex = MAX(S.VRSVFATTUSEX), @VrServicoSab = MAX(S.VRSVFATTUSAB)
   FROM SERVCLIETURN S
        /*Valor do turno da maior data de vigncia menor ou igual  data de faturamento*/
        INNER JOIN (SELECT CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, 
                           MAX(DTSERVCLIETURN) AS DTSERVCLIETURN
                     FROM SERVCLIETURN
                     WHERE DTSERVCLIETURN <= @P_DTFATURAM AND
                                 CDFILIAL   = @P_CDFILIAL   AND
                                 CDCLIENTE  = @P_CDCLIENTE  AND
                                 CDSERVFILI = @P_CDSERVFILI AND
                                 CDTURNO    = @P_CDTURNO
                    GROUP BY CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO) MV
           ON MV.CDFILIAL = S.CDFILIAL AND
              MV.CDCLIENTE = S.CDCLIENTE AND
              MV.CDSERVFILI = S.CDSERVFILI AND
              MV.CDTURNO = S.CDTURNO AND
              MV.DTSERVCLIETURN = S.DTSERVCLIETURN
        /*E que seja a ltima alterao para a data de vigncia*/
        INNER JOIN (SELECT CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, 
                           DTSERVCLIETURN, MAX(DTALTSERVCLIETURN) AS DTALTSERVCLIETURN
                     FROM SERVCLIETURN
                     WHERE DTSERVCLIETURN <= @P_DTFATURAM AND
                                 CDFILIAL   = @P_CDFILIAL   AND
                                 CDCLIENTE  = @P_CDCLIENTE  AND
                                 CDSERVFILI = @P_CDSERVFILI AND
                                 CDTURNO    = @P_CDTURNO
                    GROUP BY CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, DTSERVCLIETURN) MA
           ON MA.CDFILIAL = S.CDFILIAL AND
              MA.CDCLIENTE = S.CDCLIENTE AND
              MA.CDSERVFILI = S.CDSERVFILI AND
              MA.CDTURNO = S.CDTURNO AND
              MA.DTSERVCLIETURN = S.DTSERVCLIETURN AND
              MA.DTALTSERVCLIETURN = S.DTALTSERVCLIETURN
   WHERE S.CDFILIAL   = @P_CDFILIAL   AND
         S.CDCLIENTE  = @P_CDCLIENTE  AND
         S.CDSERVFILI = @P_CDSERVFILI AND
         S.CDTURNO    = @P_CDTURNO;

      IF (@VrServico IS NULL) BEGIN
         SET @VrServico = 0;
      END
      ELSE BEGIN
         SELECT @VrCount = COUNT(*)
         FROM FERIFILI
         WHERE CDFILIAL = @P_CDFILIAL AND
               DTFERIFILI = @P_DTFATURAM;

         IF (@VRCOUNT = 0) BEGIN
            SELECT @VRCOUNT = COUNT(*)
            FROM FERICARD
            WHERE CDFILIAL   = @P_CDFILIAL AND
                  DTFERICARD = @P_DTFATURAM;
         END;

         IF (@VrCount > 0) BEGIN
            IF (@VrServicoFer IS NOT NULL) AND (@VrServicoFer <> 0) BEGIN
               SET @VrServico = @VrServicoFer;
            END;
         END
         ELSE BEGIN
            IF (DATEPART(DW,@P_DTFATURAM) = 1) AND
               (@VrServicoDom IS NOT NULL) AND
               (@VrServicoDom <> 0) BEGIN
               SET @VrServico = @VrServicoDom;
            END;
            IF (DATEPART(DW,@P_DTFATURAM) = 2) AND
               (@VrServicoSeg IS NOT NULL) AND
               (@VrServicoSeg <> 0) BEGIN
               SET @VrServico = @VrServicoSeg;
            END;
            IF (DATEPART(DW,@P_DTFATURAM) = 3) AND
               (@VrServicoTer IS NOT NULL) AND
               (@VrServicoTer <> 0) BEGIN
               SET @VrServico = @VrServicoTer;
            END;
            IF (DATEPART(DW,@P_DTFATURAM) = 4) AND
               (@VrServicoQua IS NOT NULL) AND
               (@VrServicoQua <> 0) BEGIN
               SET @VrServico = @VrServicoQua;
            END;
            IF (DATEPART(DW,@P_DTFATURAM) = 5) AND
               (@VrServicoQui IS NOT NULL) AND
               (@VrServicoQui <> 0) BEGIN
               SET @VrServico = @VrServicoQui;
            END;
            IF (DATEPART(DW,@P_DTFATURAM) = 6) AND
               (@VrServicoSex IS NOT NULL) AND
               (@VrServicoSex <> 0) BEGIN
               SET @VrServico = @VrServicoSex;
            END;
            IF (DATEPART(DW,@P_DTFATURAM) = 7) AND
               (@VrServicoSab IS NOT NULL) AND
               (@VrServicoSab <> 0) BEGIN
               SET @VrServico = @VrServicoSab;
            END;
         END;
      END;

      IF (@VrServico = 0) BEGIN
         SET @VrServico = TEKNISA.CalcValrServ(@P_CDFILIAL, @P_CDCLIENTE, @P_CDSERVFILI, @P_DTFATURAM, @P_CDTURNO);
      END;
      RETURN(@VrServico);
END
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'DSNMSERVICO' AND
                 TYPE = 'P' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP PROCEDURE DSNMSERVICO
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'DSNMSERVICO' AND
                 TYPE = 'FN' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP FUNCTION DSNMSERVICO
GO

CREATE FUNCTION DSNMSERVICO
(@P_CDFILIAL   VARCHAR(04),
 @P_CDCLIENTE  VARCHAR(21),
 @P_CDSERVFILI VARCHAR(05),
 @P_DTFATURAM  DATETIME)
 RETURNS VARCHAR(400)

AS
BEGIN
   DECLARE @DsServico      VARCHAR(400);
   DECLARE @DsServicoFer   VARCHAR(400);
   DECLARE @DsServicoDom   VARCHAR(400);
   DECLARE @DsServicoSeg   VARCHAR(400);
   DECLARE @DsServicoTer   VARCHAR(400);
   DECLARE @DsServicoQua   VARCHAR(400);
   DECLARE @DsServicoQui   VARCHAR(400);
   DECLARE @DsServicoSex   VARCHAR(400);
   DECLARE @DsServicoSab   VARCHAR(400);
   DECLARE @DsServicoExc   VARCHAR(400);
   DECLARE @VrCount        NUMERIC;

   SET @DsServicoExc = NULL;

   SELECT @DsServico    = ISNULL(DSEMISSERCLI, NULL), @DsServicoDom = ISNULL(DSPRODEMISDOM,NULL),
          @DsServicoSeg = ISNULL(DSPRODEMISSEG,NULL), @DsServicoTer = ISNULL(DSPRODEMISTER,NULL),
          @DsServicoQua = ISNULL(DSPRODEMISQUA,NULL), @DsServicoQui = ISNULL(DSPRODEMISQUI,NULL),
          @DsServicoSex = ISNULL(DSPRODEMISSEX,NULL), @DsServicoSab = ISNULL(DSPRODEMISSAB,NULL),
          @DsServicoFer = ISNULL(DSPRODEMISFER, NULL)
   FROM SERVCLIE
   WHERE CDCLIENTE  = @P_CDCLIENTE  AND
         CDFILIAL   = @P_CDFILIAL   AND
         CDSERVFILI = @P_CDSERVFILI;

   SELECT @VrCount = COUNT(*)
   FROM FERIFILI
   WHERE CDFILIAL   = @P_CDFILIAL  AND
         DTFERIFILI = @P_DTFATURAM;

   IF (@VRCOUNT = 0) BEGIN
      SELECT @VRCOUNT = COUNT(*)
      FROM FERICARD
      WHERE CDFILIAL   = @P_CDFILIAL AND
            DTFERICARD = @P_DTFATURAM;
   END;


      IF (@VrCount > 0) BEGIN
         IF (@DsServicoFer IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoFer;
         END;
      END
      ELSE BEGIN
         IF (DATEPART(DW,@P_DTFATURAM) = 1) AND
            (@DsServicoDom IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoDom;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 2) AND
            (@DsServicoSeg IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoSeg;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 3) AND
            (@DsServicoTer IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoTer;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 4) AND
            (@DsServicoQua IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoQua;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 5) AND
            (@DsServicoQui IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoQui;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 6) AND
            (@DsServicoSex IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoSex;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 7) AND
            (@DsServicoSab IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoSab;
         END;
      END;
      IF (@DsServicoExc IS NULL) BEGIN
         SET @DsServicoExc = @DsServico;
      END;
      RETURN(@DsServicoExc);
END
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'DSNMSERVICOTUR' AND
                 TYPE = 'P' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP PROCEDURE DSNMSERVICOTUR
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'DSNMSERVICOTUR' AND
                 TYPE = 'FN' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP FUNCTION DSNMSERVICOTUR
GO

CREATE FUNCTION DSNMSERVICOTUR
(@P_CDFILIAL   VARCHAR(04),
 @P_CDCLIENTE  VARCHAR(21),
 @P_CDSERVFILI VARCHAR(05),
 @P_DTFATURAM  DATETIME,
 @P_CDTURNO    VARCHAR(01))
 RETURNS VARCHAR(400)

AS
BEGIN

   DECLARE @DsServico      VARCHAR(400);
   DECLARE @DsServicoFer   VARCHAR(400);
   DECLARE @DsServicoDom   VARCHAR(400);
   DECLARE @DsServicoSeg   VARCHAR(400);
   DECLARE @DsServicoTer   VARCHAR(400);
   DECLARE @DsServicoQua   VARCHAR(400);
   DECLARE @DsServicoQui   VARCHAR(400);
   DECLARE @DsServicoSex   VARCHAR(400);
   DECLARE @DsServicoSab   VARCHAR(400);
   DECLARE @DsServicoExc   VARCHAR(400);
   DECLARE @VrCount        NUMERIC;

   SET @DsServicoExc = NULL;

   SELECT @DsServico    = ISNULL(S.DSEMISTURCLI, NULL) , @DsServicoDom = ISNULL(S.DSPREMISTUDOM, NULL),
          @DsServicoSeg = ISNULL(S.DSPREMISTUSEG,NULL) , @DsServicoTer = ISNULL(S.DSPREMISTUTER, NULL),
          @DsServicoQua = ISNULL(S.DSPREMISTUQUA,NULL), @DsServicoQui = ISNULL(S.DSPREMISTUQUI,NULL),
          @DsServicoSex = ISNULL(S.DSPREMISTUSEX,NULL) , @DsServicoSab = ISNULL(S.DSPREMISTUSAB,NULL),
          @DsServicoFer = ISNULL(S.DSPREMISTUFER,NULL)
    FROM SERVCLIETURN S
        /*Valor do turno da maior data de vigncia menor ou igual  data de faturamento*/
        INNER JOIN (SELECT CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, 
                           MAX(DTSERVCLIETURN) AS DTSERVCLIETURN
                     FROM SERVCLIETURN
                     WHERE DTSERVCLIETURN <= @P_DTFATURAM AND
                                 CDFILIAL   = @P_CDFILIAL   AND
                                 CDCLIENTE  = @P_CDCLIENTE  AND
                                 CDSERVFILI = @P_CDSERVFILI AND
                                 CDTURNO    = @P_CDTURNO
                    GROUP BY CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO) MV
           ON MV.CDFILIAL = S.CDFILIAL AND
              MV.CDCLIENTE = S.CDCLIENTE AND
              MV.CDSERVFILI = S.CDSERVFILI AND
              MV.CDTURNO = S.CDTURNO AND
              MV.DTSERVCLIETURN = S.DTSERVCLIETURN
        /*E que seja a ltima alterao para a data de vigncia*/
        INNER JOIN (SELECT CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, 
                           DTSERVCLIETURN, MAX(DTALTSERVCLIETURN) AS DTALTSERVCLIETURN
                     FROM SERVCLIETURN
                     WHERE DTSERVCLIETURN <= @P_DTFATURAM AND
                                 CDFILIAL   = @P_CDFILIAL   AND
                                 CDCLIENTE  = @P_CDCLIENTE  AND
                                 CDSERVFILI = @P_CDSERVFILI AND
                                 CDTURNO    = @P_CDTURNO
                    GROUP BY CDFILIAL, CDCLIENTE, CDSERVFILI, CDTURNO, DTSERVCLIETURN) MA
           ON MA.CDFILIAL = S.CDFILIAL AND
              MA.CDCLIENTE = S.CDCLIENTE AND
              MA.CDSERVFILI = S.CDSERVFILI AND
              MA.CDTURNO = S.CDTURNO AND
              MA.DTSERVCLIETURN = S.DTSERVCLIETURN AND
              MA.DTALTSERVCLIETURN = S.DTALTSERVCLIETURN
    WHERE S.CDCLIENTE  = @P_CDCLIENTE  AND
          S.CDFILIAL   = @P_CDFILIAL   AND
          S.CDSERVFILI = @P_CDSERVFILI AND
          S.CDTURNO    = @P_CDTURNO;

   SELECT @VrCount = COUNT(*)
   FROM FERIFILI
   WHERE CDFILIAL   = @P_CDFILIAL  AND
         DTFERIFILI = @P_DTFATURAM;

   IF (@VRCOUNT = 0) BEGIN
      SELECT @VRCOUNT = COUNT(*)
      FROM FERICARD
      WHERE CDFILIAL   = @P_CDFILIAL AND
            DTFERICARD = @P_DTFATURAM;
   END;

      IF (@VrCount > 0) BEGIN
         IF (@DsServicoFer IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoFer;
         END;
      END
      ELSE BEGIN
         IF (DATEPART(DW,@P_DTFATURAM) = 1) AND
            (@DsServicoDom IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoDom;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 2) AND
            (@DsServicoSeg IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoSeg;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 3) AND
            (@DsServicoTer IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoTer;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 4) AND
            (@DsServicoQua IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoQua;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 5) AND
            (@DsServicoQui IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoQui;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 6) AND
            (@DsServicoSex IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoSex;
         END;
         IF (DATEPART(DW,@P_DTFATURAM) = 7) AND
            (@DsServicoSab IS NOT NULL) BEGIN
            SET @DsServicoExc = @DsServicoSab;
         END;
      END;
      IF (@DsServicoExc IS NULL) BEGIN
         SET @DsServicoExc = @DsServico;
         IF (@DsServicoExc IS NULL) BEGIN
            SET @DsServicoExc = TEKNISA.DsNmServico(@P_CDFILIAL, @P_CDCLIENTE, @P_CDSERVFILI, @P_DTFATURAM);
            IF (@DsServicoExc IS NULL) BEGIN
               SELECT @DsServicoExc = NMSERVICO
               FROM SERVICO
               WHERE CDFILIAL   = @P_CDFILIAL AND
                     CDSERVFILI = @P_CDSERVFILI;
            END;
         END;
      END;
      RETURN(@DsServicoExc);
END
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'OPENEFETMINCUR' AND
                 TYPE = 'P' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP PROCEDURE OPENEFETMINCUR
GO

CREATE PROCEDURE OPENEFETMINCUR (@C_MINEFETMES  CURSOR VARYING OUTPUT,
                                 @P_CDFILIAL    VARCHAR(4),
                                 @P_DATAINI     DATETIME,
                                 @P_DATAFIM     DATETIME,
                                 @P_IDFATUPLAN  VARCHAR(1),
                                 @P_SERVMINEFETMES VARCHAR(4000)) AS 
BEGIN
   DECLARE @V_CDCLIENTE VARCHAR(21);
   
   SELECT @V_CDCLIENTE = MAX(CDCLIENTE)
     FROM CLIENFILIAL
    WHERE CDFILIAL = @P_CDFILIAL
      AND IDCLIENPRIN = 'S';
   
   /*ABRE CURSOR QUE RETORNARA O ITEM COM A DIFERENCA DE EFETIVOS E O VALOR DO SERVICO PARA INSERIR O ITEM NA NOTA*/ 
   SET @C_MINEFETMES = CURSOR FOR
      SELECT T.CDFILIAL, T.NMTURNO, T.CDSERVFILI,(T.QTMINEFET - T.QTEFETIVOS) QTEFETIVOS, 
             T.DSMINEFET, T.CDPRODUTO, T.DTBASE, T.VRSERVICO
        FROM 
           (SELECT MI.CDFILIAL, MI.NMTURNO, SM.CDSERVFILI,MI.QTMINEFET ,SUM(SM.QTEFETIVOS)QTEFETIVOS, MI.DSMINEFET, 
                   TEKNISA.CALCVALRSERVTUR (@P_CDFILIAL,@V_CDCLIENTE,SM.CDSERVFILI,TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM), SM.CDTURNO) VRSERVICO,
                   MI.CDPRODUTO, TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM) DTBASE
              FROM SUM_EFETIVOS SM, CLIENFILIAL CF, MINEFETMESTU MI, TURNOSERV TS
             WHERE SM.CDFILIAL     = @P_CDFILIAL 
               AND SM.CDFILIAL     = MI.CDFILIAL
               AND SM.CDFILIAL     = TS.CDFILIAL
               AND MI.NMTURNO      = TS.NMTURNO
               AND SM.CDTURNO      = TS.CDTURNO
               AND SM.CDFILIAL     = CF.CDFILIAL 
               AND SM.CDSERVFILI  = TS.CDSERVFILI
               AND (SM.DTFATURAM BETWEEN DATEADD(MM,-1,TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM))+1 AND TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM) )
               AND SM.CDTURNO IS NOT NULL
               AND SM.CDFILIAL     = CF.CDFILIAL
               AND SM.CDCLIENTE    = CF.CDCLIENTE
               AND ((MI.IDTERCEIROS = 'N' AND CF.IDCLIENPRIN = 'S') OR (MI.IDTERCEIROS = 'S'))
               AND ((@P_IDFATUPLAN  = 'N' AND SM.IDFATUPLAN = 'F') OR (@P_IDFATUPLAN = 'S' )) 
             GROUP BY MI.CDFILIAL, MI.NMTURNO, SM.CDSERVFILI, MI.QTMINEFET, MI.DSMINEFET, 
                      TEKNISA.CALCVALRSERVTUR (@P_CDFILIAL,@V_CDCLIENTE,SM.CDSERVFILI,TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM), SM.CDTURNO),
                      MI.CDPRODUTO, TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM)) T 
             
      UNION ALL
             
      SELECT T.CDFILIAL, T.NMTURNO, T.CDSERVFILI, (T.QTMINEFET - T.QTEFETIVOS) QTEFETIVOS, T.DSMINEFET, 
             T.CDPRODUTO, T.DTBASE, T.VRSERVICO
        FROM
           (SELECT MI.CDFILIAL, NULL NMTURNO, MI.CDSERVFILI,MI.QTMINEFET, SUM(SM.QTEFETIVOS)QTEFETIVOS, MI.DSMINEFET,
                   TEKNISA.CALCVALRSERV (@P_CDFILIAL,@V_CDCLIENTE,SM.CDSERVFILI,TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM), NULL) VRSERVICO, 
                   SM.CDPRODUTO, TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM) DTBASE 
              FROM SUM_EFETIVOS SM, CLIENFILIAL CF , MINEFETMES MI 
             WHERE SM.CDFILIAL   = @P_CDFILIAL 
               AND SM.CDFILIAL   = MI.CDFILIAL
               AND SM.CDSERVFILI = MI.CDSERVFILI
               AND (SM.DTFATURAM BETWEEN DATEADD(MM,-1,TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM))+1 AND TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM) )
               AND SM.CDFILIAL   = CF.CDFILIAL
               AND SM.CDCLIENTE  = CF.CDCLIENTE
               AND ((MI.IDTERCEIROS = 'N' AND CF.IDCLIENPRIN = 'S') OR (MI.IDTERCEIROS = 'S'))
               AND ((@P_IDFATUPLAN  = 'N' AND SM.IDFATUPLAN = 'F') OR (@P_IDFATUPLAN = 'S' )) 
               AND SM.CDTURNO IS NULL
               AND (CHARINDEX(MI.CDSERVFILI,@P_SERVMINEFETMES ) = 0)
             GROUP BY MI.CDFILIAL, MI.CDSERVFILI, MI.QTMINEFET, MI.DSMINEFET,
                      TEKNISA.CALCVALRSERV (@P_CDFILIAL,@V_CDCLIENTE,SM.CDSERVFILI,TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM), NULL), 
                      SM.CDPRODUTO, TEKNISA.CALCULADTBASE(MI.NRDIABASE,@P_DATAINI,@P_DATAFIM)) T
      OPEN @C_MINEFETMES;        
END
GO

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCULADTBASE' AND
                 TYPE = 'FN' 			     AND
                 U.UID = O.UID           AND
                 U.NAME = USER)
DROP FUNCTION CALCULADTBASE
GO

CREATE FUNCTION CALCULADTBASE (@P_NRDIABASE   NUMERIC,
                               @P_DATAINI     DATETIME,
                               @P_DATAFIM     DATETIME) 
                RETURNS DATETIME 
AS                       
BEGIN
   DECLARE @V_NRDIABASE VARCHAR(2);
   DECLARE @V_DATABASE  DATETIME; 
   
   SET @V_NRDIABASE = RIGHT(REPLICATE('0',2)+ CONVERT(VARCHAR, @P_NRDIABASE),2);	
   
   IF (MONTH(@P_DATAINI) <> MONTH(@P_DATAFIM)) BEGIN /*SE MES INICIAL <> MES FINAL, VERIFICA EM QUAL MES O DIA BASE SERA CONSIDERADO */
      IF CONVERT(VARCHAR,DAY(@P_DATAINI)) <= @V_NRDIABASE BEGIN /*SE DIA BASE ESTA NO MES INICIAL*/
         IF @V_NRDIABASE >= CONVERT(VARCHAR,DATEADD(MM,1,@P_DATAINI)-DAY(@P_DATAINI)) BEGIN /*SE DIA BASE > ULTIMO DIA DO MES, DIA BASE VIRA ULTIMO DIA DO MES*/
            SET @V_DATABASE = DATEADD(MM,1,@P_DATAINI)-DAY(@P_DATAINI);
         END
         ELSE BEGIN
            SET @V_DATABASE = CONVERT(DATETIME, @V_NRDIABASE + '/' + CONVERT(VARCHAR,MONTH(@P_DATAINI)) + '/' + CONVERT(VARCHAR,YEAR(@P_DATAINI)));
         END;
      END   
      ELSE BEGIN /*SENAO ESTA NO MES FINAL*/
         SET @V_DATABASE = CONVERT(DATETIME, @V_NRDIABASE + '/' + CONVERT(VARCHAR,MONTH(@P_DATAFIM)) + '/' + CONVERT(VARCHAR,YEAR(@P_DATAFIM))); 
      END;
   END
   ELSE BEGIN
      IF @V_NRDIABASE >= CONVERT(VARCHAR,DATEADD(MM,1,@P_DATAFIM)-DAY(@P_DATAFIM)) BEGIN /*SE DIA BASE > ULTIMO DIA DO MES, DIA BASE VIRA ULTIMO DIA DO MES*/
         SET @V_NRDIABASE = CONVERT(VARCHAR,DATEADD(MM,1,@P_DATAFIM)-DAY(@P_DATAFIM));
      END;
      IF (@V_NRDIABASE >= CONVERT(VARCHAR,DAY(@P_DATAINI))) AND (@V_NRDIABASE <= CONVERT(VARCHAR,DAY(@P_DATAFIM))) BEGIN
         SET @V_DATABASE = CONVERT(DATETIME,@V_NRDIABASE + '/' + CONVERT(VARCHAR,MONTH(@P_DATAFIM)) + '/' + CONVERT(VARCHAR,YEAR(@P_DATAFIM)));    
      END;
   END;
   RETURN (@V_DATABASE);
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'UTIL_APURAC','5.65.000';
GO

